import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { AchievementService } from '../../service/platform/achievement.service';
import { CDTO_achievement, CVO_achievement, FVO_achievement, QDTO_achievement, QVO_achievement, UDTO_achievement, UVAO_achievement } from '../../interface/platform/achievement.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['成果'])
@Controller('/achievement')
export class AchievementController extends BaseController {
  @Inject()
  service: AchievementService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_achievement })
  async create(@Body() data: CDTO_achievement) {
    const dbData = await this.service.create(data);
    const result = new CVO_achievement(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_achievement })
  async query(@Query() filter: QDTO_achievement, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_achievement(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/list')
  async list() {
    const list = await this.service.list(this.ctx.filter);
    const data = list.data;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_achievement })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_achievement(data);
    return result;
  }

  @Get('/detail/:id')
  @ApiResponse({ type: FVO_achievement })
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    return data;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_achievement })
  async update(@Param('id') id: string, @Body() body: UDTO_achievement) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
