import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CollectionService } from '../../service/platform/collection.service';
import { CDTO_collection, CVO_collection, FVO_collection, QDTO_collection, QVO_collection, UDTO_collection, UVAO_collection } from '../../interface/platform/collection.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['收藏'])
@Controller('/collection')
export class CollectionController extends BaseController {
  @Inject()
  service: CollectionService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_collection })
  async create(@Body() data: CDTO_collection) {
    const dbData = await this.service.create(data);
    const result = new CVO_collection(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_collection })
  async query(@Query() filter: QDTO_collection, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_collection(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_collection })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_collection(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_collection })
  async update(@Param('id') id: string, @Body() body: UDTO_collection) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }

  @Post('/cancel')
  @Validate()
  @ApiResponse({ type: CVO_collection })
  async cancel(@Body() data: CDTO_collection) {
    await this.service.cancel(data);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
