import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { MatchService } from '../../service/platform/match.service';
import { CDTO_match, CVO_match, FVO_match, QDTO_match, QVO_match, UDTO_match, UVAO_match } from '../../interface/platform/match.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['创新大赛'])
@Controller('/match')
export class MatchController extends BaseController {
  @Inject()
  service: MatchService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_match })
  async create(@Body() data: CDTO_match) {
    const dbData = await this.service.create(data);
    const result = new CVO_match(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_match })
  async query(@Query() filter: QDTO_match, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_match(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_match })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_match(data);
    return result;
  }

  @Get('/detail/:id')
  @ApiResponse({ type: FVO_match })
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    return data;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_match })
  async update(@Param('id') id: string, @Body() body: UDTO_match) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
