import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ProjectService } from '../../service/platform/project.service';
import { CDTO_project, CVO_project, FVO_project, QDTO_project, QVO_project, UDTO_project, UVAO_project } from '../../interface/platform/project.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['项目'])
@Controller('/project')
export class ProjectController extends BaseController {
  @Inject()
  service: ProjectService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_project })
  async create(@Body() data: CDTO_project) {
    const dbData = await this.service.create(data);
    const result = new CVO_project(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_project })
  async query(@Query() filter: QDTO_project, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_project(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/list')
  async list() {
    const list = await this.service.list(this.ctx.filter);
    const data = list.data;
    const total = list.total;
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_project })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_project(data);
    return result;
  }

  @Get('/detail/:id')
  @ApiResponse({ type: FVO_project })
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    return data;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_project })
  async update(@Param('id') id: string, @Body() body: UDTO_project) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
