import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TagsService } from '../../service/platform/tags.service';
import { CDTO_tags, CVO_tags, FVO_tags, QDTO_tags, QVO_tags, UDTO_tags, UVAO_tags } from '../../interface/platform/tags.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['标签'])
@Controller('/tags')
export class TagsController extends BaseController {
  @Inject()
  service: TagsService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_tags })
  async create(@Body() data: CDTO_tags) {
    const dbData = await this.service.create(data);
    const result = new CVO_tags(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_tags })
  async query(@Query() filter: QDTO_tags, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit, sort: { sort: 1 } });
    const data = [];
    for (const i of list) {
      const newData = new QVO_tags(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_tags })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_tags(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_tags })
  async update(@Param('id') id: string, @Body() body: UDTO_tags) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
