import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { DeptService } from '../../service/system/dept.service';
import { CDTO_dept, CVO_dept, FVO_dept, QDTO_dept, QVO_dept, UDTO_dept, UVAO_dept } from '../../interface/system/dept.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['部门表'])
@Controller('/dept')
export class DeptController extends BaseController {
  controllerCode = 'system_dept';
  @Inject()
  service: DeptService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_dept })
  async create(@Body() data: CDTO_dept) {
    const dbData = await this.service.create(data);
    const result = new CVO_dept(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_dept })
  async query() {
    const data = await this.service.queryAll();
    return data;
  }
  @Get('/nextLevel/:id')
  @ApiQuery({ name: 'nextLevel' })
  @ApiResponse({ type: QVO_dept })
  async nextLevel(@Param('id') id: string, @Query('skip') skip: number, @Query('limit') limit: number) {
    const { data, total } = await this.service.getNextLevel(id, { skip, limit });
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_dept })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_dept(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_dept })
  async update(@Param('id') id: string, @Body() body: UDTO_dept) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
