import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { UserService } from '../../service/system/user.service';
import { CDTO_user, CVO_user, FVO_user, QDTO_user, QVO_user, UDTO_user, UVAO_user } from '../../interface/system/user.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['平台用户'])
@Controller('/user')
export class UserController extends BaseController {
  controllerCode = 'user_user';
  @Inject()
  service: UserService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_user })
  async create(@Body() data: CDTO_user) {
    const arr = await this.service.createBefore(data);
    const dbData = await this.service.create(arr);
    const result = new CVO_user(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_user })
  async query(@Query() filter: QDTO_user, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_user(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_user })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_user(data);
    return result;
  }

  @Get('/detail/:id')
  @ApiResponse({ type: FVO_user })
  async detail(@Param('id') id: string) {
    const data = await this.service.detail(id);
    const result = new FVO_user(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_user })
  async update(@Param('id') id: string, @Body() body: UDTO_user) {
    const result = await this.service.updateOne(id, body);
    await this.service.updateAfter(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
