import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { CompetitionService } from '../../service/users/competition.service';
import { CDTO_competition, CVO_competition, FVO_competition, QDTO_competition, QVO_competition, UDTO_competition, UVAO_competition } from '../../interface/users/competition.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
@ApiTags(['创业大赛'])
@Controller('/competition')
export class CompetitionController extends BaseController {
  @Inject()
  service: CompetitionService;

  @Inject()
  utilService: UtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_competition })
  async create(@Body() data: CDTO_competition) {
    const dbData = await this.service.create(data);
    const result = new CVO_competition(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_competition })
  async query(@Query() filter: QDTO_competition, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_competition(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_competition })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_competition(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_competition })
  async update(@Param('id') id: string, @Body() body: UDTO_competition) {
    const result = await this.service.updateOne(id, body);
    await this.utilService.updateUserAfter(id, body, 'Competition');
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
