import { Body, Controller, Del, Get, Inject, Param, Post, Query } from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { StateService } from '../../service/users/state.service';
import { CDTO_state, CVO_state, FVO_state, QDTO_state, QVO_state, UDTO_state, UVAO_state } from '../../interface/users/state.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
import { UtilService } from '../../service/util.service';
@ApiTags(['政府部门'])
@Controller('/state')
export class StateController extends BaseController {
  @Inject()
  service: StateService;

  @Inject()
  utilService: UtilService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_state })
  async create(@Body() data: CDTO_state) {
    const dbData = await this.service.create(data);
    const result = new CVO_state(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_state })
  async query(@Query() filter: QDTO_state, @Query('skip') skip: number, @Query('limit') limit: number) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_state(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_state })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_state(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_state })
  async update(@Param('id') id: string, @Body() body: UDTO_state) {
    const result = await this.service.updateOne(id, body);
    await this.utilService.updateUserAfter(id, body, 'State');
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
