import { App, Config, IMiddleware, Inject, MidwayWebRouterService } from '@midwayjs/core';
import { Middleware } from '@midwayjs/decorator';
import { NextFunction, Context, Application } from '@midwayjs/koa';
import { RedisService } from '@midwayjs/redis';
import { get } from 'lodash';
import { DataRecordService } from '../service/record/dataRecord.service';
import { Types } from 'mongoose';
const ObjectId = Types.ObjectId;
@Middleware()
export class DataRecordMiddleware implements IMiddleware<Context, NextFunction> {
  @App()
  app: Application;
  @Inject()
  webRouterService: MidwayWebRouterService;
  @Inject()
  redisService: RedisService;
  @Config('requestTimeLimit')
  requestTimeLimit: number;
  recordRequestList = ['post', 'delete'];
  resolve() {
    return async (ctx: Context, next: NextFunction) => {
      const routeInfo = await this.webRouterService.getMatchedRouterInfo(ctx.path, ctx.method);
      if (!routeInfo) {
        await next();
        return;
      }
      if (!this.recordRequestList.includes(routeInfo.requestMethod)) await next();
      else {
        // 只记录post和delete请求的数据变化
        const controller = get(routeInfo, 'controllerClz.name');
        const method = get(routeInfo, 'method') as string;
        // 实例操作记录服务
        const dataRecordService = await ctx.requestContext.getAsync(DataRecordService);
        // 组织操作记录数据
        const dataRecord = await dataRecordService.makeLogs(controller, method);
        // 生成操作记录数据
        const result = await dataRecordService.create(dataRecord);
        if (result) {
          const id = get(result, '_id');
          if (id) {
            // 将id放到app中.因为单例模式只能通过app获取;而不用单例模式,会引发多个监听.会重复记录
            this.app.setAttr('record_id', new ObjectId(id).toString());
          }
        }
        await next();
      }
    };
  }
}
