import { Provide } from '@midwayjs/decorator';
import { InjectEntityModel } from '@midwayjs/typegoose';
import { ReturnModelType } from '@typegoose/typegoose';
import { BaseService } from 'free-midway-component';
import { Expert } from '../../entity/users/expert.entity';
import { Collection } from '../../entity/platform/collection.entity';
import { get } from 'lodash';
type modelType = ReturnModelType<typeof Expert>;
@Provide()
export class ExpertService extends BaseService<modelType> {
  @InjectEntityModel(Expert)
  model: modelType;
  @InjectEntityModel(Collection)
  cModel: ReturnModelType<typeof Collection>;

  // 专家列表
  async list(query) {
    const { skip = 0, limit = 0, is_show, status, ...condition } = query;
    const { one, two, thr, four } = condition;
    const info: any = { is_show, status };
    if (one) info.field = { $in: one };
    if (two) info.title = { $in: two };
    if (thr) info.area = { $in: thr };
    if (four) info.area = { $in: four };
    const data = await this.model.find(info).skip(skip).limit(limit).lean();
    const total = await this.model.count(info);
    return { data, total };
  }

  // 专家详情
  async detail(id) {
    const user = this.ctx.user;
    const data = { is_collection: false };
    const arr = await this.model.findById(id).lean();
    if (arr && get(arr, '_id')) {
      if (user && user._id) {
        // 查询是否收藏该专家
        const collection = await this.cModel.findOne({ user: user._id, source: arr._id }).lean();
        if (collection) data.is_collection = true;
      }
    }
    return { ...arr, ...data };
  }
}
